eqcorrscan.utils.archive\_read.\_check\_available\_data
=======================================================

.. currentmodule:: eqcorrscan.utils.archive_read

.. autofunction:: _check_available_data